@@ -40,23 +40,26 @@ class SshClient():
         self.verbose = verbose
         self._conn = None
         self.stdin = self.stdout = self.stderr = None
+        self.lock = None
+        self.sem = asyncio.Semaphore(5)
 
     async def _open(self):
         if self._conn is None:
-            try:
-                self._conn = await asyncio.wait_for(asyncssh.connect(
-                    self.host,
-                    port=self.port,
-                    known_hosts=None,
-                    encryption_algs='+3des-cbc',
-                    kex_algs='+diffie-hellman-group1-sha1',
-                    server_host_key_algs='+ssh-dss',
-                    tunnel=self._tun,
-                    username=self.username,
-                    password=self.password),
-                                                    timeout=5.0)
-            except Exception as err:
-                raise
+            if not self.lock:
+                self.lock = asyncio.Lock()
+            async with self.lock:
+                if self._conn is None:
+                    self._conn = await asyncio.wait_for(asyncssh.connect(
+                        self.host,
+                        port=self.port,
+                        known_hosts=None,
+                        encryption_algs='+3des-cbc',
+                        kex_algs='+diffie-hellman-group1-sha1',
+                        server_host_key_algs='+ssh-dss',
+                        tunnel=self._tun,
+                        username=self.username,
+                        password=self.password),
+                                                        timeout=5.0)
 
     async def close(self):
         """Close the connection and free any resources."""
@@ -77,9 +80,7 @@ class SshClient():
 
     async def cmd(self, cmd, timeout=5.0, delimiter=None, term_type=None):
         """Send a command.  The response is returned."""
-        cmd_bckd = cmd
-        if self._conn is None:
-            await self._open()
+        await self._open()
         if self.stdin is None:
             try:
                 self.stdin, self.stdout, self.stderr = await self._conn.open_session(
@@ -120,12 +121,12 @@ class SshClient():
 
     async def scmd(self, cmd, timeout=5.0):
         """Simpler version of cmd: Send a command, the response is returned."""
-        if self._conn is None:
+        async with self.sem:
             await self._open()
-        r = await self._conn.run(cmd, timeout=timeout)
-        if self.record is not None:
-            self.record.append([cmd, r.stdout])
-        return r.stdout
+            r = await self._conn.run(cmd, timeout=timeout)
+            if self.record is not None:
+                self.record.append([cmd, r.stdout])
+            return r.stdout
 
     async def get_brmacs(self, br_name):
         """Dict of Intf:[list of Brmacs] pairs is returned."""
